You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@celix.apache.org by ab...@apache.org on 2012/12/05 10:06:34 UTC

svn commit: r1417320 [5/7] - in /incubator/celix/trunk: dependency_manager/private/src/ dependency_manager/public/include/ deployment_admin/private/include/ deployment_admin/private/src/ device_access/device_access/private/include/ device_access/device...

Modified: incubator/celix/trunk/framework/public/include/bundle_context.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/bundle_context.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/bundle_context.h (original)
+++ incubator/celix/trunk/framework/public/include/bundle_context.h Wed Dec  5 09:05:46 2012
@@ -40,32 +40,32 @@ typedef struct bundleContext *bundle_con
 #include "properties.h"
 #include "array_list.h"
 
-FRAMEWORK_EXPORT celix_status_t bundleContext_create(FRAMEWORK framework, BUNDLE bundle, bundle_context_t *bundle_context);
+FRAMEWORK_EXPORT celix_status_t bundleContext_create(framework_t framework, bundle_t bundle, bundle_context_t *bundle_context);
 FRAMEWORK_EXPORT celix_status_t bundleContext_destroy(bundle_context_t context);
 
-FRAMEWORK_EXPORT celix_status_t bundleContext_getBundle(bundle_context_t context, BUNDLE *bundle);
-FRAMEWORK_EXPORT celix_status_t bundleContext_getFramework(bundle_context_t context, FRAMEWORK *framework);
+FRAMEWORK_EXPORT celix_status_t bundleContext_getBundle(bundle_context_t context, bundle_t *bundle);
+FRAMEWORK_EXPORT celix_status_t bundleContext_getFramework(bundle_context_t context, framework_t *framework);
 FRAMEWORK_EXPORT celix_status_t bundleContext_getMemoryPool(bundle_context_t context, apr_pool_t **memory_pool);
 
-FRAMEWORK_EXPORT celix_status_t bundleContext_installBundle(bundle_context_t context, char * location, BUNDLE *bundle);
-FRAMEWORK_EXPORT celix_status_t bundleContext_installBundle2(bundle_context_t context, char * location, char *inputFile, BUNDLE *bundle);
+FRAMEWORK_EXPORT celix_status_t bundleContext_installBundle(bundle_context_t context, char * location, bundle_t *bundle);
+FRAMEWORK_EXPORT celix_status_t bundleContext_installBundle2(bundle_context_t context, char * location, char *inputFile, bundle_t *bundle);
 
 FRAMEWORK_EXPORT celix_status_t bundleContext_registerService(bundle_context_t context, char * serviceName, void * svcObj,
-        PROPERTIES properties, SERVICE_REGISTRATION *service_registration);
+        properties_t properties, service_registration_t *service_registration);
 FRAMEWORK_EXPORT celix_status_t bundleContext_registerServiceFactory(bundle_context_t context, char * serviceName, service_factory_t factory,
-        PROPERTIES properties, SERVICE_REGISTRATION *service_registration);
+        properties_t properties, service_registration_t *service_registration);
 
-FRAMEWORK_EXPORT celix_status_t bundleContext_getServiceReferences(bundle_context_t context, const char * serviceName, char * filter, ARRAY_LIST *service_references);
-FRAMEWORK_EXPORT celix_status_t bundleContext_getServiceReference(bundle_context_t context, char * serviceName, SERVICE_REFERENCE *service_reference);
+FRAMEWORK_EXPORT celix_status_t bundleContext_getServiceReferences(bundle_context_t context, const char * serviceName, char * filter, array_list_t *service_references);
+FRAMEWORK_EXPORT celix_status_t bundleContext_getServiceReference(bundle_context_t context, char * serviceName, service_reference_t *service_reference);
 
-FRAMEWORK_EXPORT celix_status_t bundleContext_getService(bundle_context_t context, SERVICE_REFERENCE reference, void **service_instance);
-FRAMEWORK_EXPORT celix_status_t bundleContext_ungetService(bundle_context_t context, SERVICE_REFERENCE reference, bool *result);
+FRAMEWORK_EXPORT celix_status_t bundleContext_getService(bundle_context_t context, service_reference_t reference, void **service_instance);
+FRAMEWORK_EXPORT celix_status_t bundleContext_ungetService(bundle_context_t context, service_reference_t reference, bool *result);
 
-FRAMEWORK_EXPORT celix_status_t bundleContext_getBundles(bundle_context_t context, ARRAY_LIST *bundles);
-FRAMEWORK_EXPORT celix_status_t bundleContext_getBundleById(bundle_context_t context, long id, BUNDLE *bundle);
+FRAMEWORK_EXPORT celix_status_t bundleContext_getBundles(bundle_context_t context, array_list_t *bundles);
+FRAMEWORK_EXPORT celix_status_t bundleContext_getBundleById(bundle_context_t context, long id, bundle_t *bundle);
 
-FRAMEWORK_EXPORT celix_status_t bundleContext_addServiceListener(bundle_context_t context, SERVICE_LISTENER listener, char * filter);
-FRAMEWORK_EXPORT celix_status_t bundleContext_removeServiceListener(bundle_context_t context, SERVICE_LISTENER listener);
+FRAMEWORK_EXPORT celix_status_t bundleContext_addServiceListener(bundle_context_t context, service_listener_t listener, char * filter);
+FRAMEWORK_EXPORT celix_status_t bundleContext_removeServiceListener(bundle_context_t context, service_listener_t listener);
 
 FRAMEWORK_EXPORT celix_status_t bundleContext_addBundleListener(bundle_context_t context, bundle_listener_t listener);
 FRAMEWORK_EXPORT celix_status_t bundleContext_removeBundleListener(bundle_context_t context, bundle_listener_t listener);

Modified: incubator/celix/trunk/framework/public/include/bundle_event.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/bundle_event.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/bundle_event.h (original)
+++ incubator/celix/trunk/framework/public/include/bundle_event.h Wed Dec  5 09:05:46 2012
@@ -48,7 +48,7 @@ typedef struct bundle_event *bundle_even
 #include "bundle.h"
 
 struct bundle_event {
-	BUNDLE bundle;
+	bundle_t bundle;
 	bundle_event_type_e type;
 };
 

Modified: incubator/celix/trunk/framework/public/include/bundle_listener.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/bundle_listener.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/bundle_listener.h (original)
+++ incubator/celix/trunk/framework/public/include/bundle_listener.h Wed Dec  5 09:05:46 2012
@@ -44,7 +44,7 @@ struct bundle_listener {
 
 
 
-#endif /* SERVICE_LISTENER_H_ */
+#endif /* service_listener_t_H_ */
 
 /**
  * @}

Modified: incubator/celix/trunk/framework/public/include/bundle_revision.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/bundle_revision.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/bundle_revision.h (original)
+++ incubator/celix/trunk/framework/public/include/bundle_revision.h Wed Dec  5 09:05:46 2012
@@ -35,14 +35,14 @@
 #include "celix_errno.h"
 
 /**
- * Typedef for BUNDLE_REVISION.
+ * Typedef for bundle_revision_t.
  *
  * A bundle revision represents the content of a bundle. A revision is associated with a bundle archive.
  * An archive can have multiple revisions, each update of a bundle results in a new one.
  *
  * In a revision the content of a bundle (ZIP file) is extracted to a specified location inside the archive.
  */
-typedef struct bundleRevision * BUNDLE_REVISION;
+typedef struct bundleRevision * bundle_revision_t;
 
 /**
  * Creates a new revision for the given inputFile or location.
@@ -60,7 +60,7 @@ typedef struct bundleRevision * BUNDLE_R
  * 		- CELIX_SUCCESS when no errors are encountered.
  * 		- CELIX_ENOMEM If allocating memory for <code>bundle_revision</code> failed.
  */
-celix_status_t bundleRevision_create(apr_pool_t *pool, char *root, char *location, long revisionNr, char *inputFile, BUNDLE_REVISION *bundle_revision);
+celix_status_t bundleRevision_create(apr_pool_t *pool, char *root, char *location, long revisionNr, char *inputFile, bundle_revision_t *bundle_revision);
 
 /**
  * Retrieves the revision number of the given revision.
@@ -72,7 +72,7 @@ celix_status_t bundleRevision_create(apr
  * 		- CELIX_SUCCESS when no errors are encountered.
  * 		- CELIX_ILLEGAL_ARGUMENT If <code>revision</code> is illegal.
  */
-celix_status_t bundleRevision_getNumber(BUNDLE_REVISION revision, long *revisionNr);
+celix_status_t bundleRevision_getNumber(bundle_revision_t revision, long *revisionNr);
 
 /**
  * Retrieves the location of the given revision.
@@ -84,7 +84,7 @@ celix_status_t bundleRevision_getNumber(
  * 		- CELIX_SUCCESS when no errors are encountered.
  * 		- CELIX_ILLEGAL_ARGUMENT If <code>revision</code> is illegal.
  */
-celix_status_t bundleRevision_getLocation(BUNDLE_REVISION revision, char **location);
+celix_status_t bundleRevision_getLocation(bundle_revision_t revision, char **location);
 
 /**
  * Retrieves the root of the given revision.
@@ -96,7 +96,7 @@ celix_status_t bundleRevision_getLocatio
  * 		- CELIX_SUCCESS when no errors are encountered.
  * 		- CELIX_ILLEGAL_ARGUMENT If <code>revision</code> is illegal.
  */
-celix_status_t bundleRevision_getRoot(BUNDLE_REVISION revision, char **root);
+celix_status_t bundleRevision_getRoot(bundle_revision_t revision, char **root);
 
 #endif /* BUNDLE_REVISION_H_ */
 

Modified: incubator/celix/trunk/framework/public/include/bundle_state.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/bundle_state.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/bundle_state.h (original)
+++ incubator/celix/trunk/framework/public/include/bundle_state.h Wed Dec  5 09:05:46 2012
@@ -37,6 +37,6 @@ enum bundleState
 	BUNDLE_ACTIVE = 0x00000020,
 };
 
-typedef enum bundleState BUNDLE_STATE;
+typedef enum bundleState bundle_state_e;
 
 #endif /* BUNDLE_STATE_H_ */

Modified: incubator/celix/trunk/framework/public/include/capability.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/capability.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/capability.h (original)
+++ incubator/celix/trunk/framework/public/include/capability.h Wed Dec  5 09:05:46 2012
@@ -27,14 +27,14 @@
 #ifndef CAPABILITY_H_
 #define CAPABILITY_H_
 
-typedef struct capability *CAPABILITY;
+typedef struct capability *capability_t;
 
 #include "hash_map.h"
 #include "module.h"
 
-celix_status_t capability_create(apr_pool_t *pool, MODULE module, HASH_MAP directives, HASH_MAP attributes, CAPABILITY *capability);
-celix_status_t capability_getServiceName(CAPABILITY capability, char **serviceName);
-celix_status_t capability_getVersion(CAPABILITY capability, VERSION *version);
-celix_status_t capability_getModule(CAPABILITY capability, MODULE *module);
+celix_status_t capability_create(apr_pool_t *pool, module_t module, hash_map_t directives, hash_map_t attributes, capability_t *capability);
+celix_status_t capability_getServiceName(capability_t capability, char **serviceName);
+celix_status_t capability_getVersion(capability_t capability, version_t *version);
+celix_status_t capability_getModule(capability_t capability, module_t *module);
 
 #endif /* CAPABILITY_H_ */

Modified: incubator/celix/trunk/framework/public/include/filter.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/filter.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/filter.h (original)
+++ incubator/celix/trunk/framework/public/include/filter.h Wed Dec  5 09:05:46 2012
@@ -38,7 +38,7 @@ typedef struct filter * filter_t;
 filter_t filter_create(char * filterString, apr_pool_t *pool);
 void filter_destroy(filter_t filter);
 
-celix_status_t filter_match(filter_t filter, PROPERTIES properties, bool *result);
+celix_status_t filter_match(filter_t filter, properties_t properties, bool *result);
 
 celix_status_t filter_getString(filter_t filter, char **filterStr);
 

Modified: incubator/celix/trunk/framework/public/include/framework.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/framework.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/framework.h (original)
+++ incubator/celix/trunk/framework/public/include/framework.h Wed Dec  5 09:05:46 2012
@@ -28,7 +28,7 @@
 #define FRAMEWORK_H_
 
 typedef struct activator * ACTIVATOR;
-typedef struct framework * FRAMEWORK;
+typedef struct framework * framework_t;
 
 #include "manifest.h"
 #include "wire.h"
@@ -43,61 +43,61 @@ typedef struct framework * FRAMEWORK;
 #include "bundle_context.h"
 #include "framework_exports.h"
 
-FRAMEWORK_EXPORT celix_status_t framework_create(FRAMEWORK *framework, apr_pool_t *memoryPool, PROPERTIES config);
-FRAMEWORK_EXPORT celix_status_t framework_destroy(FRAMEWORK framework);
+FRAMEWORK_EXPORT celix_status_t framework_create(framework_t *framework, apr_pool_t *memoryPool, properties_t config);
+FRAMEWORK_EXPORT celix_status_t framework_destroy(framework_t framework);
 
-FRAMEWORK_EXPORT celix_status_t fw_init(FRAMEWORK framework);
-FRAMEWORK_EXPORT celix_status_t framework_start(FRAMEWORK framework);
-FRAMEWORK_EXPORT void framework_stop(FRAMEWORK framework);
+FRAMEWORK_EXPORT celix_status_t fw_init(framework_t framework);
+FRAMEWORK_EXPORT celix_status_t framework_start(framework_t framework);
+FRAMEWORK_EXPORT void framework_stop(framework_t framework);
 
-FRAMEWORK_EXPORT celix_status_t fw_getProperty(FRAMEWORK framework, const char *name, char **value);
+FRAMEWORK_EXPORT celix_status_t fw_getProperty(framework_t framework, const char *name, char **value);
 
-FRAMEWORK_EXPORT celix_status_t fw_installBundle(FRAMEWORK framework, BUNDLE * bundle, char * location, char *inputFile);
-FRAMEWORK_EXPORT celix_status_t fw_uninstallBundle(FRAMEWORK framework, BUNDLE bundle);
+FRAMEWORK_EXPORT celix_status_t fw_installBundle(framework_t framework, bundle_t * bundle, char * location, char *inputFile);
+FRAMEWORK_EXPORT celix_status_t fw_uninstallBundle(framework_t framework, bundle_t bundle);
 
-FRAMEWORK_EXPORT celix_status_t framework_getBundleEntry(FRAMEWORK framework, BUNDLE bundle, char *name, apr_pool_t *pool, char **entry);
+FRAMEWORK_EXPORT celix_status_t framework_getBundleEntry(framework_t framework, bundle_t bundle, char *name, apr_pool_t *pool, char **entry);
 
-FRAMEWORK_EXPORT celix_status_t fw_startBundle(FRAMEWORK framework, BUNDLE bundle, int options);
-FRAMEWORK_EXPORT celix_status_t framework_updateBundle(FRAMEWORK framework, BUNDLE bundle, char *inputFile);
-FRAMEWORK_EXPORT celix_status_t fw_stopBundle(FRAMEWORK framework, BUNDLE bundle, bool record);
+FRAMEWORK_EXPORT celix_status_t fw_startBundle(framework_t framework, bundle_t bundle, int options);
+FRAMEWORK_EXPORT celix_status_t framework_updateBundle(framework_t framework, bundle_t bundle, char *inputFile);
+FRAMEWORK_EXPORT celix_status_t fw_stopBundle(framework_t framework, bundle_t bundle, bool record);
 
-FRAMEWORK_EXPORT celix_status_t fw_registerService(FRAMEWORK framework, SERVICE_REGISTRATION * registration, BUNDLE bundle, char * serviceName, void * svcObj, PROPERTIES properties);
-FRAMEWORK_EXPORT celix_status_t fw_registerServiceFactory(FRAMEWORK framework, SERVICE_REGISTRATION * registration, BUNDLE bundle, char * serviceName, service_factory_t factory, PROPERTIES properties);
-FRAMEWORK_EXPORT void fw_unregisterService(SERVICE_REGISTRATION registration);
+FRAMEWORK_EXPORT celix_status_t fw_registerService(framework_t framework, service_registration_t * registration, bundle_t bundle, char * serviceName, void * svcObj, properties_t properties);
+FRAMEWORK_EXPORT celix_status_t fw_registerServiceFactory(framework_t framework, service_registration_t * registration, bundle_t bundle, char * serviceName, service_factory_t factory, properties_t properties);
+FRAMEWORK_EXPORT void fw_unregisterService(service_registration_t registration);
 
-FRAMEWORK_EXPORT celix_status_t fw_getServiceReferences(FRAMEWORK framework, ARRAY_LIST *references, BUNDLE bundle, const char * serviceName, char * filter);
-FRAMEWORK_EXPORT void * fw_getService(FRAMEWORK framework, BUNDLE bundle, SERVICE_REFERENCE reference);
-FRAMEWORK_EXPORT bool framework_ungetService(FRAMEWORK framework, BUNDLE bundle, SERVICE_REFERENCE reference);
-FRAMEWORK_EXPORT celix_status_t fw_getBundleRegisteredServices(FRAMEWORK framework, apr_pool_t *pool, BUNDLE bundle, ARRAY_LIST *services);
-FRAMEWORK_EXPORT celix_status_t fw_getBundleServicesInUse(FRAMEWORK framework, BUNDLE bundle, ARRAY_LIST *services);
+FRAMEWORK_EXPORT celix_status_t fw_getServiceReferences(framework_t framework, array_list_t *references, bundle_t bundle, const char * serviceName, char * filter);
+FRAMEWORK_EXPORT void * fw_getService(framework_t framework, bundle_t bundle, service_reference_t reference);
+FRAMEWORK_EXPORT bool framework_ungetService(framework_t framework, bundle_t bundle, service_reference_t reference);
+FRAMEWORK_EXPORT celix_status_t fw_getBundleRegisteredServices(framework_t framework, apr_pool_t *pool, bundle_t bundle, array_list_t *services);
+FRAMEWORK_EXPORT celix_status_t fw_getBundleServicesInUse(framework_t framework, bundle_t bundle, array_list_t *services);
 
-FRAMEWORK_EXPORT void fw_addServiceListener(FRAMEWORK framework, BUNDLE bundle, SERVICE_LISTENER listener, char * filter);
-FRAMEWORK_EXPORT void fw_removeServiceListener(FRAMEWORK framework, BUNDLE bundle, SERVICE_LISTENER listener);
+FRAMEWORK_EXPORT void fw_addServiceListener(framework_t framework, bundle_t bundle, service_listener_t listener, char * filter);
+FRAMEWORK_EXPORT void fw_removeServiceListener(framework_t framework, bundle_t bundle, service_listener_t listener);
 
-FRAMEWORK_EXPORT celix_status_t fw_addBundleListener(FRAMEWORK framework, BUNDLE bundle, bundle_listener_t listener);
-FRAMEWORK_EXPORT celix_status_t fw_removeBundleListener(FRAMEWORK framework, BUNDLE bundle, bundle_listener_t listener);
+FRAMEWORK_EXPORT celix_status_t fw_addBundleListener(framework_t framework, bundle_t bundle, bundle_listener_t listener);
+FRAMEWORK_EXPORT celix_status_t fw_removeBundleListener(framework_t framework, bundle_t bundle, bundle_listener_t listener);
 
-FRAMEWORK_EXPORT void fw_serviceChanged(FRAMEWORK framework, SERVICE_EVENT_TYPE eventType, SERVICE_REGISTRATION registration, PROPERTIES oldprops);
+FRAMEWORK_EXPORT void fw_serviceChanged(framework_t framework, service_event_type_e eventType, service_registration_t registration, properties_t oldprops);
 
-FRAMEWORK_EXPORT celix_status_t fw_isServiceAssignable(FRAMEWORK fw, BUNDLE requester, SERVICE_REFERENCE reference, bool *assignable);
+FRAMEWORK_EXPORT celix_status_t fw_isServiceAssignable(framework_t fw, bundle_t requester, service_reference_t reference, bool *assignable);
 
 //bundle_archive_t fw_createArchive(long id, char * location);
 //void revise(bundle_archive_t archive, char * location);
 FRAMEWORK_EXPORT celix_status_t getManifest(bundle_archive_t archive, apr_pool_t *pool, MANIFEST *manifest);
 
-FRAMEWORK_EXPORT BUNDLE findBundle(bundle_context_t context);
-FRAMEWORK_EXPORT SERVICE_REGISTRATION findRegistration(SERVICE_REFERENCE reference);
+FRAMEWORK_EXPORT bundle_t findBundle(bundle_context_t context);
+FRAMEWORK_EXPORT service_registration_t findRegistration(service_reference_t reference);
 
-FRAMEWORK_EXPORT SERVICE_REFERENCE listToArray(ARRAY_LIST list);
-FRAMEWORK_EXPORT celix_status_t framework_markResolvedModules(FRAMEWORK framework, HASH_MAP wires);
+FRAMEWORK_EXPORT service_reference_t listToArray(array_list_t list);
+FRAMEWORK_EXPORT celix_status_t framework_markResolvedModules(framework_t framework, hash_map_t wires);
 
-FRAMEWORK_EXPORT celix_status_t framework_waitForStop(FRAMEWORK framework);
+FRAMEWORK_EXPORT celix_status_t framework_waitForStop(framework_t framework);
 
-FRAMEWORK_EXPORT ARRAY_LIST framework_getBundles(FRAMEWORK framework);
-FRAMEWORK_EXPORT BUNDLE framework_getBundle(FRAMEWORK framework, char * location);
-FRAMEWORK_EXPORT BUNDLE framework_getBundleById(FRAMEWORK framework, long id);
+FRAMEWORK_EXPORT array_list_t framework_getBundles(framework_t framework);
+FRAMEWORK_EXPORT bundle_t framework_getBundle(framework_t framework, char * location);
+FRAMEWORK_EXPORT bundle_t framework_getBundleById(framework_t framework, long id);
 
-FRAMEWORK_EXPORT celix_status_t framework_getMemoryPool(FRAMEWORK framework, apr_pool_t **pool);
-FRAMEWORK_EXPORT celix_status_t framework_getFrameworkBundle(FRAMEWORK framework, BUNDLE *bundle);
+FRAMEWORK_EXPORT celix_status_t framework_getMemoryPool(framework_t framework, apr_pool_t **pool);
+FRAMEWORK_EXPORT celix_status_t framework_getFrameworkBundle(framework_t framework, bundle_t *bundle);
 
 #endif /* FRAMEWORK_H_ */

Modified: incubator/celix/trunk/framework/public/include/listener_hook_service.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/listener_hook_service.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/listener_hook_service.h (original)
+++ incubator/celix/trunk/framework/public/include/listener_hook_service.h Wed Dec  5 09:05:46 2012
@@ -44,8 +44,8 @@ struct listener_hook_info {
 
 struct listener_hook_service {
 	void *handle;
-	celix_status_t (*added)(void *hook, ARRAY_LIST listeners);
-	celix_status_t (*removed)(void *hook, ARRAY_LIST listeners);
+	celix_status_t (*added)(void *hook, array_list_t listeners);
+	celix_status_t (*removed)(void *hook, array_list_t listeners);
 };
 
 #endif /* LISTENER_HOOK_SERVICE_H_ */

Modified: incubator/celix/trunk/framework/public/include/manifest.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/manifest.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/manifest.h (original)
+++ incubator/celix/trunk/framework/public/include/manifest.h Wed Dec  5 09:05:46 2012
@@ -34,8 +34,8 @@
 
 struct manifest {
 	apr_pool_t *pool;
-	PROPERTIES mainAttributes;
-	HASH_MAP attributes;
+	properties_t mainAttributes;
+	hash_map_t attributes;
 };
 
 typedef struct manifest * MANIFEST;
@@ -44,8 +44,8 @@ celix_status_t manifest_create(apr_pool_
 celix_status_t manifest_createFromFile(apr_pool_t *pool, char *filename, MANIFEST *manifest);
 
 void manifest_clear(MANIFEST manifest);
-PROPERTIES manifest_getMainAttributes(MANIFEST manifest);
-celix_status_t manifest_getEntries(MANIFEST manifest, HASH_MAP *map);
+properties_t manifest_getMainAttributes(MANIFEST manifest);
+celix_status_t manifest_getEntries(MANIFEST manifest, hash_map_t *map);
 
 celix_status_t manifest_read(MANIFEST manifest, char *filename);
 void manifest_write(MANIFEST manifest, char * filename);

Modified: incubator/celix/trunk/framework/public/include/module.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/module.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/module.h (original)
+++ incubator/celix/trunk/framework/public/include/module.h Wed Dec  5 09:05:46 2012
@@ -27,7 +27,7 @@
 #ifndef MODULE_H_
 #define MODULE_H_
 
-typedef struct module *MODULE;
+typedef struct module *module_t;
 
 #include "celixbool.h"
 #include "linkedlist.h"
@@ -37,35 +37,35 @@ typedef struct module *MODULE;
 #include "bundle.h"
 #include "framework_exports.h"
 
-MODULE module_create(MANIFEST headerMap, char * moduleId, BUNDLE bundle);
-MODULE module_createFrameworkModule(BUNDLE bundle);
-void module_destroy(MODULE module);
+module_t module_create(MANIFEST headerMap, char * moduleId, bundle_t bundle);
+module_t module_createFrameworkModule(bundle_t bundle);
+void module_destroy(module_t module);
 
 FRAMEWORK_EXPORT unsigned int module_hash(void * module);
 FRAMEWORK_EXPORT int module_equals(void * module, void * compare);
 
-FRAMEWORK_EXPORT WIRE module_getWire(MODULE module, char * serviceName);
+FRAMEWORK_EXPORT wire_t module_getWire(module_t module, char * serviceName);
 
-FRAMEWORK_EXPORT VERSION module_getVersion(MODULE module);
-FRAMEWORK_EXPORT celix_status_t module_getSymbolicName(MODULE module, char **symbolicName);
-FRAMEWORK_EXPORT char * module_getId(MODULE module);
-FRAMEWORK_EXPORT LINKED_LIST module_getWires(MODULE module);
-FRAMEWORK_EXPORT void module_setWires(MODULE module, LINKED_LIST wires);
-FRAMEWORK_EXPORT bool module_isResolved(MODULE module);
-FRAMEWORK_EXPORT void module_setResolved(MODULE module);
-FRAMEWORK_EXPORT BUNDLE module_getBundle(MODULE module);
-
-FRAMEWORK_EXPORT LINKED_LIST module_getRequirements(MODULE module);
-FRAMEWORK_EXPORT LINKED_LIST module_getCapabilities(MODULE module);
-
-FRAMEWORK_EXPORT ARRAY_LIST module_getDependentImporters(MODULE module);
-FRAMEWORK_EXPORT void module_addDependentImporter(MODULE module, MODULE importer);
-FRAMEWORK_EXPORT void module_removeDependentImporter(MODULE module, MODULE importer);
-
-FRAMEWORK_EXPORT ARRAY_LIST module_getDependentRequirers(MODULE module);
-FRAMEWORK_EXPORT void module_addDependentRequirer(MODULE module, MODULE requirer);
-FRAMEWORK_EXPORT void module_removeDependentRequirer(MODULE module, MODULE requirer);
+FRAMEWORK_EXPORT version_t module_getVersion(module_t module);
+FRAMEWORK_EXPORT celix_status_t module_getSymbolicName(module_t module, char **symbolicName);
+FRAMEWORK_EXPORT char * module_getId(module_t module);
+FRAMEWORK_EXPORT linked_list_t module_getWires(module_t module);
+FRAMEWORK_EXPORT void module_setWires(module_t module, linked_list_t wires);
+FRAMEWORK_EXPORT bool module_isResolved(module_t module);
+FRAMEWORK_EXPORT void module_setResolved(module_t module);
+FRAMEWORK_EXPORT bundle_t module_getBundle(module_t module);
+
+FRAMEWORK_EXPORT linked_list_t module_getRequirements(module_t module);
+FRAMEWORK_EXPORT linked_list_t module_getCapabilities(module_t module);
+
+FRAMEWORK_EXPORT array_list_t module_getDependentImporters(module_t module);
+FRAMEWORK_EXPORT void module_addDependentImporter(module_t module, module_t importer);
+FRAMEWORK_EXPORT void module_removeDependentImporter(module_t module, module_t importer);
+
+FRAMEWORK_EXPORT array_list_t module_getDependentRequirers(module_t module);
+FRAMEWORK_EXPORT void module_addDependentRequirer(module_t module, module_t requirer);
+FRAMEWORK_EXPORT void module_removeDependentRequirer(module_t module, module_t requirer);
 
-FRAMEWORK_EXPORT ARRAY_LIST module_getDependents(MODULE module);
+FRAMEWORK_EXPORT array_list_t module_getDependents(module_t module);
 
 #endif /* MODULE_H_ */

Modified: incubator/celix/trunk/framework/public/include/properties.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/properties.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/properties.h (original)
+++ incubator/celix/trunk/framework/public/include/properties.h Wed Dec  5 09:05:46 2012
@@ -30,15 +30,15 @@
 #include "hash_map.h"
 #include "framework_exports.h"
 
-typedef HASH_MAP PROPERTIES;
+typedef hash_map_t properties_t;
 
-FRAMEWORK_EXPORT PROPERTIES properties_create(void);
-FRAMEWORK_EXPORT void properties_destroy(PROPERTIES properties);
-FRAMEWORK_EXPORT PROPERTIES properties_load(char * filename);
-FRAMEWORK_EXPORT void properties_store(PROPERTIES properties, char * file, char * header);
+FRAMEWORK_EXPORT properties_t properties_create(void);
+FRAMEWORK_EXPORT void properties_destroy(properties_t properties);
+FRAMEWORK_EXPORT properties_t properties_load(char * filename);
+FRAMEWORK_EXPORT void properties_store(properties_t properties, char * file, char * header);
 
-FRAMEWORK_EXPORT char * properties_get(PROPERTIES properties, char * key);
-FRAMEWORK_EXPORT char * properties_getWithDefault(PROPERTIES properties, char * key, char * defaultValue);
-FRAMEWORK_EXPORT char * properties_set(PROPERTIES properties, char * key, char * value);
+FRAMEWORK_EXPORT char * properties_get(properties_t properties, char * key);
+FRAMEWORK_EXPORT char * properties_getWithDefault(properties_t properties, char * key, char * defaultValue);
+FRAMEWORK_EXPORT char * properties_set(properties_t properties, char * key, char * value);
 
 #endif /* PROPERTIES_H_ */

Modified: incubator/celix/trunk/framework/public/include/requirement.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/requirement.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/requirement.h (original)
+++ incubator/celix/trunk/framework/public/include/requirement.h Wed Dec  5 09:05:46 2012
@@ -27,16 +27,16 @@
 #ifndef REQUIREMENT_H_
 #define REQUIREMENT_H_
 
-typedef struct requirement *REQUIREMENT;
+typedef struct requirement *requirement_t;
 
 #include "capability.h"
 #include "hash_map.h"
 #include "version_range.h"
 
-celix_status_t requirement_create(apr_pool_t *pool, HASH_MAP directives, HASH_MAP attributes, REQUIREMENT *requirement);
-celix_status_t requirement_getVersionRange(REQUIREMENT requirement, VERSION_RANGE *range);
-celix_status_t requirement_getTargetName(REQUIREMENT requirement, char **targetName);
+celix_status_t requirement_create(apr_pool_t *pool, hash_map_t directives, hash_map_t attributes, requirement_t *requirement);
+celix_status_t requirement_getVersionRange(requirement_t requirement, version_range_t *range);
+celix_status_t requirement_getTargetName(requirement_t requirement, char **targetName);
 
-celix_status_t requirement_isSatisfied(REQUIREMENT requirement, CAPABILITY capability, bool *inRange);
+celix_status_t requirement_isSatisfied(requirement_t requirement, capability_t capability, bool *inRange);
 
 #endif /* REQUIREMENT_H_ */

Modified: incubator/celix/trunk/framework/public/include/service_event.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/service_event.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/service_event.h (original)
+++ incubator/celix/trunk/framework/public/include/service_event.h Wed Dec  5 09:05:46 2012
@@ -29,8 +29,8 @@
 #ifndef SERVICE_EVENT_H_
 #define SERVICE_EVENT_H_
 
-typedef enum serviceEventType SERVICE_EVENT_TYPE;
-typedef struct serviceEvent * SERVICE_EVENT;
+typedef enum serviceEventType service_event_type_e;
+typedef struct serviceEvent *service_event_t;
 
 #include "service_reference.h"
 
@@ -43,8 +43,8 @@ enum serviceEventType
 };
 
 struct serviceEvent {
-	SERVICE_REFERENCE reference;
-	SERVICE_EVENT_TYPE type;
+	service_reference_t reference;
+	service_event_type_e type;
 };
 
 #endif /* SERVICE_EVENT_H_ */

Modified: incubator/celix/trunk/framework/public/include/service_factory.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/service_factory.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/service_factory.h (original)
+++ incubator/celix/trunk/framework/public/include/service_factory.h Wed Dec  5 09:05:46 2012
@@ -37,8 +37,8 @@ typedef struct service_factory * service
 
 struct service_factory {
     void *factory;
-    celix_status_t (*getService)(void *factory, BUNDLE bundle, SERVICE_REGISTRATION registration, void **service);
-    celix_status_t (*ungetService)(void *factory, BUNDLE bundle, SERVICE_REGISTRATION registration);
+    celix_status_t (*getService)(void *factory, bundle_t bundle, service_registration_t registration, void **service);
+    celix_status_t (*ungetService)(void *factory, bundle_t bundle, service_registration_t registration);
 };
 
 

Modified: incubator/celix/trunk/framework/public/include/service_listener.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/service_listener.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/service_listener.h (original)
+++ incubator/celix/trunk/framework/public/include/service_listener.h Wed Dec  5 09:05:46 2012
@@ -31,7 +31,7 @@
 
 #include <apr_general.h>
 
-typedef struct serviceListener * SERVICE_LISTENER;
+typedef struct serviceListener * service_listener_t;
 
 #include "celix_errno.h"
 #include "service_event.h"
@@ -39,7 +39,7 @@ typedef struct serviceListener * SERVICE
 struct serviceListener {
 	apr_pool_t *pool;
 	void * handle;
-	celix_status_t (*serviceChanged)(void * listener, SERVICE_EVENT event);
+	celix_status_t (*serviceChanged)(void * listener, service_event_t event);
 };
 
 

Modified: incubator/celix/trunk/framework/public/include/service_reference.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/service_reference.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/service_reference.h (original)
+++ incubator/celix/trunk/framework/public/include/service_reference.h Wed Dec  5 09:05:46 2012
@@ -27,7 +27,7 @@
 #ifndef SERVICE_REFERENCE_H_
 #define SERVICE_REFERENCE_H_
 
-typedef struct serviceReference * SERVICE_REFERENCE;
+typedef struct serviceReference * service_reference_t;
 
 #include "celixbool.h"
 #include "array_list.h"
@@ -35,17 +35,17 @@ typedef struct serviceReference * SERVIC
 #include "bundle.h"
 #include "framework_exports.h"
 
-celix_status_t serviceReference_create(apr_pool_t *pool, BUNDLE bundle, SERVICE_REGISTRATION registration, SERVICE_REFERENCE *reference);
+celix_status_t serviceReference_create(apr_pool_t *pool, bundle_t bundle, service_registration_t registration, service_reference_t *reference);
 
-FRAMEWORK_EXPORT celix_status_t serviceReference_invalidate(SERVICE_REFERENCE reference);
+FRAMEWORK_EXPORT celix_status_t serviceReference_invalidate(service_reference_t reference);
 
-FRAMEWORK_EXPORT celix_status_t serviceReference_getServiceRegistration(SERVICE_REFERENCE reference, SERVICE_REGISTRATION *registration);
-FRAMEWORK_EXPORT celix_status_t serviceReference_getBundle(SERVICE_REFERENCE reference, BUNDLE *bundle);
+FRAMEWORK_EXPORT celix_status_t serviceReference_getServiceRegistration(service_reference_t reference, service_registration_t *registration);
+FRAMEWORK_EXPORT celix_status_t serviceReference_getBundle(service_reference_t reference, bundle_t *bundle);
 
-FRAMEWORK_EXPORT bool serviceReference_isAssignableTo(SERVICE_REFERENCE reference, BUNDLE requester, char * serviceName);
+FRAMEWORK_EXPORT bool serviceReference_isAssignableTo(service_reference_t reference, bundle_t requester, char * serviceName);
 
-FRAMEWORK_EXPORT celix_status_t serviceReference_getUsingBundles(SERVICE_REFERENCE reference, apr_pool_t *pool, ARRAY_LIST *bundles);
-FRAMEWORK_EXPORT celix_status_t serviceReference_equals(SERVICE_REFERENCE reference, SERVICE_REFERENCE compareTo, bool *equal);
+FRAMEWORK_EXPORT celix_status_t serviceReference_getUsingBundles(service_reference_t reference, apr_pool_t *pool, array_list_t *bundles);
+FRAMEWORK_EXPORT celix_status_t serviceReference_equals(service_reference_t reference, service_reference_t compareTo, bool *equal);
 FRAMEWORK_EXPORT unsigned int serviceReference_hashCode(void *referenceP);
 FRAMEWORK_EXPORT int serviceReference_equals2(void *reference1, void *reference2);
 

Modified: incubator/celix/trunk/framework/public/include/service_registration.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/service_registration.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/service_registration.h (original)
+++ incubator/celix/trunk/framework/public/include/service_registration.h Wed Dec  5 09:05:46 2012
@@ -29,27 +29,27 @@
 
 #include "celixbool.h"
 
-typedef struct serviceRegistration * SERVICE_REGISTRATION;
+typedef struct serviceRegistration * service_registration_t;
 
 #include "service_registry.h"
 #include "array_list.h"
 #include "bundle.h"
 #include "framework_exports.h"
 
-SERVICE_REGISTRATION serviceRegistration_create(apr_pool_t *pool, SERVICE_REGISTRY registry, BUNDLE bundle, char * serviceName, long serviceId, void * serviceObject, PROPERTIES dictionary);
-SERVICE_REGISTRATION serviceRegistration_createServiceFactory(apr_pool_t *pool, SERVICE_REGISTRY registry, BUNDLE bundle, char * serviceName, long serviceId, void * serviceObject, PROPERTIES dictionary);
-void serviceRegistration_destroy(SERVICE_REGISTRATION registration);
-
-FRAMEWORK_EXPORT bool serviceRegistration_isValid(SERVICE_REGISTRATION registration);
-FRAMEWORK_EXPORT void serviceRegistration_invalidate(SERVICE_REGISTRATION registration);
-FRAMEWORK_EXPORT celix_status_t serviceRegistration_unregister(SERVICE_REGISTRATION registration);
-
-FRAMEWORK_EXPORT celix_status_t serviceRegistration_getService(SERVICE_REGISTRATION registration, BUNDLE bundle, void **service);
-
-FRAMEWORK_EXPORT celix_status_t serviceRegistration_getProperties(SERVICE_REGISTRATION registration, PROPERTIES *properties);
-FRAMEWORK_EXPORT celix_status_t serviceRegistration_getRegistry(SERVICE_REGISTRATION registration, SERVICE_REGISTRY *registry);
-FRAMEWORK_EXPORT celix_status_t serviceRegistration_getServiceReferences(SERVICE_REGISTRATION registration, ARRAY_LIST *references);
-FRAMEWORK_EXPORT celix_status_t serviceRegistration_getBundle(SERVICE_REGISTRATION registration, BUNDLE *bundle);
-FRAMEWORK_EXPORT celix_status_t serviceRegistration_getServiceName(SERVICE_REGISTRATION registration, char **serviceName);
+service_registration_t serviceRegistration_create(apr_pool_t *pool, service_registry_t registry, bundle_t bundle, char * serviceName, long serviceId, void * serviceObject, properties_t dictionary);
+service_registration_t serviceRegistration_createServiceFactory(apr_pool_t *pool, service_registry_t registry, bundle_t bundle, char * serviceName, long serviceId, void * serviceObject, properties_t dictionary);
+void serviceRegistration_destroy(service_registration_t registration);
+
+FRAMEWORK_EXPORT bool serviceRegistration_isValid(service_registration_t registration);
+FRAMEWORK_EXPORT void serviceRegistration_invalidate(service_registration_t registration);
+FRAMEWORK_EXPORT celix_status_t serviceRegistration_unregister(service_registration_t registration);
+
+FRAMEWORK_EXPORT celix_status_t serviceRegistration_getService(service_registration_t registration, bundle_t bundle, void **service);
+
+FRAMEWORK_EXPORT celix_status_t serviceRegistration_getProperties(service_registration_t registration, properties_t *properties);
+FRAMEWORK_EXPORT celix_status_t serviceRegistration_getRegistry(service_registration_t registration, service_registry_t *registry);
+FRAMEWORK_EXPORT celix_status_t serviceRegistration_getServiceReferences(service_registration_t registration, array_list_t *references);
+FRAMEWORK_EXPORT celix_status_t serviceRegistration_getBundle(service_registration_t registration, bundle_t *bundle);
+FRAMEWORK_EXPORT celix_status_t serviceRegistration_getServiceName(service_registration_t registration, char **serviceName);
 
 #endif /* SERVICE_REGISTRATION_H_ */

Modified: incubator/celix/trunk/framework/public/include/service_registry.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/service_registry.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/service_registry.h (original)
+++ incubator/celix/trunk/framework/public/include/service_registry.h Wed Dec  5 09:05:46 2012
@@ -29,7 +29,7 @@
 
 #include <apr_general.h>
 
-typedef struct serviceRegistry * SERVICE_REGISTRY;
+typedef struct serviceRegistry * service_registry_t;
 
 #include "properties.h"
 #include "filter.h"
@@ -38,24 +38,24 @@ typedef struct serviceRegistry * SERVICE
 #include "array_list.h"
 #include "service_registration.h"
 
-SERVICE_REGISTRY serviceRegistry_create(FRAMEWORK framework, void (*serviceChanged)(FRAMEWORK, SERVICE_EVENT_TYPE, SERVICE_REGISTRATION, PROPERTIES));
-celix_status_t serviceRegistry_destroy(SERVICE_REGISTRY registry);
-celix_status_t serviceRegistry_getRegisteredServices(SERVICE_REGISTRY registry, apr_pool_t *pool, BUNDLE bundle, ARRAY_LIST *services);
-ARRAY_LIST serviceRegistry_getServicesInUse(SERVICE_REGISTRY registry, BUNDLE bundle);
-SERVICE_REGISTRATION serviceRegistry_registerService(SERVICE_REGISTRY registry, BUNDLE bundle, char * serviceName, void * serviceObject, PROPERTIES dictionary);
-SERVICE_REGISTRATION serviceRegistry_registerServiceFactory(SERVICE_REGISTRY registry, BUNDLE bundle, char * serviceName, service_factory_t factory, PROPERTIES dictionary);
-void serviceRegistry_unregisterService(SERVICE_REGISTRY registry, BUNDLE bundle, SERVICE_REGISTRATION registration);
-void serviceRegistry_unregisterServices(SERVICE_REGISTRY registry, BUNDLE bundle);
-celix_status_t serviceRegistry_getServiceReferences(SERVICE_REGISTRY registry, apr_pool_t *pool, const char *serviceName, filter_t filter, ARRAY_LIST *references);
-void * serviceRegistry_getService(SERVICE_REGISTRY registry, BUNDLE bundle, SERVICE_REFERENCE reference);
-bool serviceRegistry_ungetService(SERVICE_REGISTRY registry, BUNDLE bundle, SERVICE_REFERENCE reference);
-void serviceRegistry_ungetServices(SERVICE_REGISTRY registry, BUNDLE bundle);
-ARRAY_LIST serviceRegistry_getUsingBundles(SERVICE_REGISTRY registry, apr_pool_t *pool, SERVICE_REFERENCE reference);
-SERVICE_REGISTRATION serviceRegistry_findRegistration(SERVICE_REGISTRY registry, SERVICE_REFERENCE reference);
-celix_status_t serviceRegistry_createServiceReference(SERVICE_REGISTRY registry, apr_pool_t *pool, SERVICE_REGISTRATION registration, SERVICE_REFERENCE *reference);
+service_registry_t serviceRegistry_create(framework_t framework, void (*serviceChanged)(framework_t, service_event_type_e, service_registration_t, properties_t));
+celix_status_t serviceRegistry_destroy(service_registry_t registry);
+celix_status_t serviceRegistry_getRegisteredServices(service_registry_t registry, apr_pool_t *pool, bundle_t bundle, array_list_t *services);
+array_list_t serviceRegistry_getServicesInUse(service_registry_t registry, bundle_t bundle);
+service_registration_t serviceRegistry_registerService(service_registry_t registry, bundle_t bundle, char * serviceName, void * serviceObject, properties_t dictionary);
+service_registration_t serviceRegistry_registerServiceFactory(service_registry_t registry, bundle_t bundle, char * serviceName, service_factory_t factory, properties_t dictionary);
+void serviceRegistry_unregisterService(service_registry_t registry, bundle_t bundle, service_registration_t registration);
+void serviceRegistry_unregisterServices(service_registry_t registry, bundle_t bundle);
+celix_status_t serviceRegistry_getServiceReferences(service_registry_t registry, apr_pool_t *pool, const char *serviceName, filter_t filter, array_list_t *references);
+void * serviceRegistry_getService(service_registry_t registry, bundle_t bundle, service_reference_t reference);
+bool serviceRegistry_ungetService(service_registry_t registry, bundle_t bundle, service_reference_t reference);
+void serviceRegistry_ungetServices(service_registry_t registry, bundle_t bundle);
+array_list_t serviceRegistry_getUsingBundles(service_registry_t registry, apr_pool_t *pool, service_reference_t reference);
+service_registration_t serviceRegistry_findRegistration(service_registry_t registry, service_reference_t reference);
+celix_status_t serviceRegistry_createServiceReference(service_registry_t registry, apr_pool_t *pool, service_registration_t registration, service_reference_t *reference);
 
-celix_status_t serviceRegistry_getListenerHooks(SERVICE_REGISTRY registry, apr_pool_t *pool, ARRAY_LIST *hooks);
+celix_status_t serviceRegistry_getListenerHooks(service_registry_t registry, apr_pool_t *pool, array_list_t *hooks);
 
-celix_status_t serviceRegistry_servicePropertiesModified(SERVICE_REGISTRY registry, SERVICE_REGISTRATION registration, PROPERTIES oldprops);
+celix_status_t serviceRegistry_servicePropertiesModified(service_registry_t registry, service_registration_t registration, properties_t oldprops);
 
 #endif /* SERVICE_REGISTRY_H_ */

Modified: incubator/celix/trunk/framework/public/include/service_tracker.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/service_tracker.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/service_tracker.h (original)
+++ incubator/celix/trunk/framework/public/include/service_tracker.h Wed Dec  5 09:05:46 2012
@@ -41,13 +41,13 @@ FRAMEWORK_EXPORT celix_status_t serviceT
 FRAMEWORK_EXPORT celix_status_t serviceTracker_open(service_tracker_t tracker);
 FRAMEWORK_EXPORT celix_status_t serviceTracker_close(service_tracker_t tracker);
 
-FRAMEWORK_EXPORT SERVICE_REFERENCE serviceTracker_getServiceReference(service_tracker_t tracker);
-FRAMEWORK_EXPORT ARRAY_LIST serviceTracker_getServiceReferences(service_tracker_t tracker);
+FRAMEWORK_EXPORT service_reference_t serviceTracker_getServiceReference(service_tracker_t tracker);
+FRAMEWORK_EXPORT array_list_t serviceTracker_getServiceReferences(service_tracker_t tracker);
 
 FRAMEWORK_EXPORT void * serviceTracker_getService(service_tracker_t tracker);
-FRAMEWORK_EXPORT ARRAY_LIST serviceTracker_getServices(service_tracker_t tracker);
-FRAMEWORK_EXPORT void * serviceTracker_getServiceByReference(service_tracker_t tracker, SERVICE_REFERENCE reference);
+FRAMEWORK_EXPORT array_list_t serviceTracker_getServices(service_tracker_t tracker);
+FRAMEWORK_EXPORT void * serviceTracker_getServiceByReference(service_tracker_t tracker, service_reference_t reference);
 
-FRAMEWORK_EXPORT void serviceTracker_serviceChanged(SERVICE_LISTENER listener, SERVICE_EVENT event);
+FRAMEWORK_EXPORT void serviceTracker_serviceChanged(service_listener_t listener, service_event_t event);
 
 #endif /* SERVICE_TRACKER_H_ */

Modified: incubator/celix/trunk/framework/public/include/service_tracker_customizer.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/service_tracker_customizer.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/service_tracker_customizer.h (original)
+++ incubator/celix/trunk/framework/public/include/service_tracker_customizer.h Wed Dec  5 09:05:46 2012
@@ -33,10 +33,10 @@
 #include "celix_errno.h"
 #include "framework_exports.h"
 
-typedef celix_status_t (*addingCallback)(void *handle, SERVICE_REFERENCE reference, void **service);
-typedef celix_status_t (*addedCallback)(void * handle, SERVICE_REFERENCE reference, void * service);
-typedef celix_status_t (*modifiedCallback)(void * handle, SERVICE_REFERENCE reference, void * service);
-typedef celix_status_t (*removedCallback)(void * handle, SERVICE_REFERENCE reference, void * service);
+typedef celix_status_t (*addingCallback)(void *handle, service_reference_t reference, void **service);
+typedef celix_status_t (*addedCallback)(void * handle, service_reference_t reference, void * service);
+typedef celix_status_t (*modifiedCallback)(void * handle, service_reference_t reference, void * service);
+typedef celix_status_t (*removedCallback)(void * handle, service_reference_t reference, void * service);
 
 typedef struct serviceTrackerCustomizer *service_tracker_customizer_t;
 

Modified: incubator/celix/trunk/framework/public/include/version.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/version.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/wire.h (original)
+++ incubator/celix/trunk/framework/public/include/wire.h Wed Dec  5 09:05:46 2012
@@ -27,7 +27,7 @@
 #ifndef WIRE_H_
 #define WIRE_H_
 
-typedef struct wire *WIRE;
+typedef struct wire *wire_t;
 
 #include "requirement.h"
 #include "capability.h"
@@ -54,8 +54,8 @@ typedef struct wire *WIRE;
  * 		- CELIX_SUCCESS when no errors are encountered.
  * 		- CELIX_ENOMEM If allocating memory for <code>wire</code> failed.
  */
-celix_status_t wire_create(apr_pool_t *pool, MODULE importer, REQUIREMENT requirement,
-		MODULE exporter, CAPABILITY capability, WIRE *wire);
+celix_status_t wire_create(apr_pool_t *pool, module_t importer, requirement_t requirement,
+		module_t exporter, capability_t capability, wire_t *wire);
 
 /**
  * Getter for the capability of the exporting module.
@@ -65,7 +65,7 @@ celix_status_t wire_create(apr_pool_t *p
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
  */
-celix_status_t wire_getCapability(WIRE wire, CAPABILITY *capability);
+celix_status_t wire_getCapability(wire_t wire, capability_t *capability);
 
 /**
  * Getter for the requirement of the importing module.
@@ -75,7 +75,7 @@ celix_status_t wire_getCapability(WIRE w
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
  */
-celix_status_t wire_getRequirement(WIRE wire, REQUIREMENT *requirement);
+celix_status_t wire_getRequirement(wire_t wire, requirement_t *requirement);
 
 /**
  * Getter for the importer of the wire.
@@ -85,7 +85,7 @@ celix_status_t wire_getRequirement(WIRE 
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
  */
-celix_status_t wire_getImporter(WIRE wire, MODULE *importer);
+celix_status_t wire_getImporter(wire_t wire, module_t *importer);
 
 /**
  * Getter for the exporter of the wire.
@@ -95,7 +95,7 @@ celix_status_t wire_getImporter(WIRE wir
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
  */
-celix_status_t wire_getExporter(WIRE wire, MODULE *exporter);
+celix_status_t wire_getExporter(wire_t wire, module_t *exporter);
 
 /**
  * @}

Modified: incubator/celix/trunk/launcher/private/src/launcher.c
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/launcher/private/src/launcher.c?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/launcher/private/src/launcher.c (original)
+++ incubator/celix/trunk/launcher/private/src/launcher.c Wed Dec  5 09:05:46 2012
@@ -48,7 +48,7 @@ int main(void) {
 	// Set signal handler
 	apr_status_t rv = APR_SUCCESS;
 	apr_status_t s = APR_SUCCESS;
-	PROPERTIES config = NULL;
+	properties_t config = NULL;
 	char *autoStart = NULL;
 
 	
@@ -78,11 +78,11 @@ int main(void) {
     if (apr_pool_create(&pool, memoryPool) == APR_SUCCESS) {
 		char delims[] = " ";
 		char *result = NULL;	
-        LINKED_LIST bundles;
-		ARRAY_LIST installed = NULL;
-		BUNDLE bundle = NULL;
+        linked_list_t bundles;
+		array_list_t installed = NULL;
+		bundle_t bundle = NULL;
 		bundle_context_t context = NULL;
-		LINKED_LIST_ITERATOR iter = NULL;
+		linked_list_iterator_t iter = NULL;
 		unsigned int i;
 
         linkedList_create(pool, &bundles);
@@ -99,7 +99,7 @@ int main(void) {
         bundle_getContext(bundle, &context);
         iter = linkedListIterator_create(bundles, 0);
         while (linkedListIterator_hasNext(iter)) {
-            BUNDLE current = NULL;
+            bundle_t current = NULL;
             char * location = (char *) linkedListIterator_next(iter);
             if (bundleContext_installBundle(context, location, &current) == CELIX_SUCCESS) {
                 // Only add bundle if it is installed correctly
@@ -114,7 +114,7 @@ int main(void) {
         linkedListIterator_destroy(iter);
 
         for (i = 0; i < arrayList_size(installed); i++) {
-            BUNDLE bundle = (BUNDLE) arrayList_get(installed, i);
+            bundle_t bundle = (bundle_t) arrayList_get(installed, i);
             bundle_start(bundle, 0);
         }
 

Modified: incubator/celix/trunk/log_service/private/include/log.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/private/include/log.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/private/include/log.h (original)
+++ incubator/celix/trunk/log_service/private/include/log.h Wed Dec  5 09:05:46 2012
@@ -37,7 +37,7 @@ typedef struct log * log_t;
 
 celix_status_t log_create(apr_pool_t *pool, log_t *logger);
 celix_status_t log_addEntry(log_t log, log_entry_t entry);
-celix_status_t log_getEntries(log_t log, apr_pool_t *memory_pool, LINKED_LIST *list);
+celix_status_t log_getEntries(log_t log, apr_pool_t *memory_pool, linked_list_t *list);
 
 celix_status_t log_addLogListener(log_t logger, log_listener_t listener);
 celix_status_t log_removeLogListener(log_t logger, log_listener_t listener);

Modified: incubator/celix/trunk/log_service/private/include/log_factory.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/private/include/log_factory.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/private/include/log_factory.h (original)
+++ incubator/celix/trunk/log_service/private/include/log_factory.h Wed Dec  5 09:05:46 2012
@@ -32,8 +32,8 @@
 typedef struct log_service_factory * log_service_factory_t;
 
 celix_status_t logFactory_create(apr_pool_t *pool, log_t log, service_factory_t *factory);
-celix_status_t logFactory_getService(void *factory, BUNDLE bundle, SERVICE_REGISTRATION registration, void **service);
-celix_status_t logFactory_ungetService(void *factory, BUNDLE bundle, SERVICE_REGISTRATION registration);
+celix_status_t logFactory_getService(void *factory, bundle_t bundle, service_registration_t registration, void **service);
+celix_status_t logFactory_ungetService(void *factory, bundle_t bundle, service_registration_t registration);
 
 
 #endif /* LOG_FACTORY_H_ */

Modified: incubator/celix/trunk/log_service/private/include/log_reader_service_impl.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/private/include/log_reader_service_impl.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/private/include/log_reader_service_impl.h (original)
+++ incubator/celix/trunk/log_service/private/include/log_reader_service_impl.h Wed Dec  5 09:05:46 2012
@@ -32,7 +32,7 @@
 
 celix_status_t logReaderService_create(log_t log, apr_pool_t *pool, log_reader_data_t *reader);
 
-celix_status_t logReaderService_getLog(log_reader_data_t reader, apr_pool_t *memory_pool, LINKED_LIST *list);
+celix_status_t logReaderService_getLog(log_reader_data_t reader, apr_pool_t *memory_pool, linked_list_t *list);
 
 celix_status_t logReaderService_addLogListener(log_reader_data_t reader, log_listener_t listener);
 celix_status_t logReaderService_removeLogListener(log_reader_data_t reader, log_listener_t listener);

Modified: incubator/celix/trunk/log_service/private/include/log_service_impl.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/private/include/log_service_impl.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/private/include/log_service_impl.h (original)
+++ incubator/celix/trunk/log_service/private/include/log_service_impl.h Wed Dec  5 09:05:46 2012
@@ -30,9 +30,9 @@
 #include "log_service.h"
 #include "log.h"
 
-celix_status_t logService_create(log_t log, BUNDLE bundle, apr_pool_t *pool, log_service_data_t *logger);
+celix_status_t logService_create(log_t log, bundle_t bundle, apr_pool_t *pool, log_service_data_t *logger);
 celix_status_t logService_log(log_service_data_t logger, log_level_t level, char * message);
-celix_status_t logService_logSr(log_service_data_t logger, SERVICE_REFERENCE reference, log_level_t level, char * message);
+celix_status_t logService_logSr(log_service_data_t logger, service_reference_t reference, log_level_t level, char * message);
 
 
 #endif /* LOG_SERVICE_IMPL_H_ */

Modified: incubator/celix/trunk/log_service/private/src/log.c
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/private/src/log.c?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/private/src/log.c (original)
+++ incubator/celix/trunk/log_service/private/src/log.c Wed Dec  5 09:05:46 2012
@@ -33,11 +33,11 @@
 #include "array_list.h"
 
 struct log {
-    LINKED_LIST entries;
+    linked_list_t entries;
     apr_thread_mutex_t *lock;
 
-    ARRAY_LIST listeners;
-    ARRAY_LIST listenerEntries;
+    array_list_t listeners;
+    array_list_t listenerEntries;
 
     apr_thread_t *listenerThread;
     bool running;
@@ -123,10 +123,10 @@ celix_status_t log_addEntry(log_t log, l
     return CELIX_SUCCESS;
 }
 
-celix_status_t log_getEntries(log_t log, apr_pool_t *memory_pool, LINKED_LIST *list) {
-    LINKED_LIST entries = NULL;
+celix_status_t log_getEntries(log_t log, apr_pool_t *memory_pool, linked_list_t *list) {
+    linked_list_t entries = NULL;
     if (linkedList_create(memory_pool, &entries) == CELIX_SUCCESS) {
-        LINKED_LIST_ITERATOR iter = NULL;
+        linked_list_iterator_t iter = NULL;
 
         apr_thread_mutex_lock(log->lock);
 
@@ -265,7 +265,7 @@ void * APR_THREAD_FUNC log_listenerThrea
                     logger->running = false;
                     break;
                 } else {
-                    ARRAY_LIST_ITERATOR it = arrayListIterator_create(logger->listeners);
+                    array_list_iterator_t it = arrayListIterator_create(logger->listeners);
                     while (arrayListIterator_hasNext(it)) {
                         log_listener_t listener = arrayListIterator_next(it);
                         listener->logged(listener, entry);

Modified: incubator/celix/trunk/log_service/private/src/log_entry.c
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/private/src/log_entry.c?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/private/src/log_entry.c (original)
+++ incubator/celix/trunk/log_service/private/src/log_entry.c Wed Dec  5 09:05:46 2012
@@ -28,7 +28,7 @@
 
 #include "log_entry.h"
 
-celix_status_t logEntry_create(BUNDLE bundle, SERVICE_REFERENCE reference,
+celix_status_t logEntry_create(bundle_t bundle, service_reference_t reference,
         log_level_t level, char *message, int errorCode,
         apr_pool_t *pool, log_entry_t *entry) {
     celix_status_t status = CELIX_SUCCESS;
@@ -48,7 +48,7 @@ celix_status_t logEntry_create(BUNDLE bu
     return status;
 }
 
-celix_status_t logEntry_getBundle(log_entry_t entry, BUNDLE *bundle) {
+celix_status_t logEntry_getBundle(log_entry_t entry, bundle_t *bundle) {
     *bundle = entry->bundle;
     return CELIX_SUCCESS;
 }
@@ -68,7 +68,7 @@ celix_status_t logEntry_getMessage(log_e
     return CELIX_SUCCESS;
 }
 
-celix_status_t logEntry_getServiceReference(log_entry_t entry, SERVICE_REFERENCE *reference) {
+celix_status_t logEntry_getServiceReference(log_entry_t entry, service_reference_t *reference) {
     *reference = entry->reference;
     return CELIX_SUCCESS;
 }

Modified: incubator/celix/trunk/log_service/private/src/log_factory.c
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/private/src/log_factory.c?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/private/src/log_factory.c (original)
+++ incubator/celix/trunk/log_service/private/src/log_factory.c Wed Dec  5 09:05:46 2012
@@ -58,7 +58,7 @@ celix_status_t logFactory_create(apr_poo
     return CELIX_SUCCESS;
 }
 
-celix_status_t logFactory_getService(void *factory, BUNDLE bundle, SERVICE_REGISTRATION registration, void **service) {
+celix_status_t logFactory_getService(void *factory, bundle_t bundle, service_registration_t registration, void **service) {
     log_service_factory_t log_factory = ((service_factory_t) factory)->factory;
     log_service_t log_service = NULL;
     log_service_data_t log_service_data = NULL;
@@ -75,7 +75,7 @@ celix_status_t logFactory_getService(voi
     return CELIX_SUCCESS;
 }
 
-celix_status_t logFactory_ungetService(void *factory, BUNDLE bundle, SERVICE_REGISTRATION registration) {
+celix_status_t logFactory_ungetService(void *factory, bundle_t bundle, service_registration_t registration) {
     log_service_factory_t log_factory = ((service_factory_t) factory)->factory;
     return CELIX_SUCCESS;
 }

Modified: incubator/celix/trunk/log_service/private/src/log_reader_service_impl.c
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/private/src/log_reader_service_impl.c?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/private/src/log_reader_service_impl.c (original)
+++ incubator/celix/trunk/log_service/private/src/log_reader_service_impl.c Wed Dec  5 09:05:46 2012
@@ -49,7 +49,7 @@ celix_status_t logReaderService_create(l
     return status;
 }
 
-celix_status_t logReaderService_getLog(log_reader_data_t reader, apr_pool_t *memory_pool, LINKED_LIST *list) {
+celix_status_t logReaderService_getLog(log_reader_data_t reader, apr_pool_t *memory_pool, linked_list_t *list) {
     celix_status_t status = CELIX_SUCCESS;
 
     status = log_getEntries(reader->log, memory_pool, list);

Modified: incubator/celix/trunk/log_service/private/src/log_service_activator.c
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/private/src/log_service_activator.c?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/private/src/log_service_activator.c (original)
+++ incubator/celix/trunk/log_service/private/src/log_service_activator.c Wed Dec  5 09:05:46 2012
@@ -36,8 +36,8 @@
 
 struct logActivator {
     bundle_context_t bundleContext;
-    SERVICE_REGISTRATION logServiceFactoryReg;
-    SERVICE_REGISTRATION logReaderServiceReg;
+    service_registration_t logServiceFactoryReg;
+    service_registration_t logReaderServiceReg;
 
 };
 

Modified: incubator/celix/trunk/log_service/private/src/log_service_impl.c
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/private/src/log_service_impl.c?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/private/src/log_service_impl.c (original)
+++ incubator/celix/trunk/log_service/private/src/log_service_impl.c Wed Dec  5 09:05:46 2012
@@ -31,11 +31,11 @@
 
 struct log_service_data {
     log_t log;
-    BUNDLE bundle;
+    bundle_t bundle;
     apr_pool_t *pool;
 };
 
-celix_status_t logService_create(log_t log, BUNDLE bundle, apr_pool_t *pool, log_service_data_t *logger) {
+celix_status_t logService_create(log_t log, bundle_t bundle, apr_pool_t *pool, log_service_data_t *logger) {
     celix_status_t status = CELIX_SUCCESS;
     *logger = apr_palloc(pool, sizeof(struct log_service_data));
     if (*logger == NULL) {
@@ -53,9 +53,9 @@ celix_status_t logService_log(log_servic
     return logService_logSr(logger, NULL, level, message);
 }
 
-celix_status_t logService_logSr(log_service_data_t logger, SERVICE_REFERENCE reference, log_level_t level, char * message) {
+celix_status_t logService_logSr(log_service_data_t logger, service_reference_t reference, log_level_t level, char * message) {
     log_entry_t entry = NULL;
-    BUNDLE bundle = logger->bundle;
+    bundle_t bundle = logger->bundle;
     if (reference != NULL) {
     	serviceReference_getBundle(reference, &bundle);
     }

Modified: incubator/celix/trunk/log_service/public/include/log_entry.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/public/include/log_entry.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/public/include/log_entry.h (original)
+++ incubator/celix/trunk/log_service/public/include/log_entry.h Wed Dec  5 09:05:46 2012
@@ -30,24 +30,24 @@
 #include "log_service.h"
 
 struct log_entry {
-    BUNDLE bundle;
+    bundle_t bundle;
     int errorCode;
     log_level_t level;
     char *message;
-    SERVICE_REFERENCE reference;
+    service_reference_t reference;
     time_t time;
 };
 
 typedef struct log_entry * log_entry_t;
 
-celix_status_t logEntry_create(BUNDLE bundle, SERVICE_REFERENCE reference,
+celix_status_t logEntry_create(bundle_t bundle, service_reference_t reference,
         log_level_t level, char *message, int errorCode,
         apr_pool_t *pool, log_entry_t *entry);
-celix_status_t logEntry_getBundle(log_entry_t entry, BUNDLE *bundle);
+celix_status_t logEntry_getBundle(log_entry_t entry, bundle_t *bundle);
 celix_status_t logEntry_getErrorCode(log_entry_t entry, int *errorCode);
 celix_status_t logEntry_getLevel(log_entry_t entry, log_level_t *level);
 celix_status_t logEntry_getMessage(log_entry_t entry, char **message);
-celix_status_t logEntry_getServiceReference(log_entry_t entry, SERVICE_REFERENCE *reference);
+celix_status_t logEntry_getServiceReference(log_entry_t entry, service_reference_t *reference);
 celix_status_t logEntry_getTime(log_entry_t entry, time_t *time);
 
 #endif /* LOG_ENTRY_H_ */

Modified: incubator/celix/trunk/log_service/public/include/log_reader_service.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/public/include/log_reader_service.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/public/include/log_reader_service.h (original)
+++ incubator/celix/trunk/log_service/public/include/log_reader_service.h Wed Dec  5 09:05:46 2012
@@ -38,7 +38,7 @@ typedef struct log_reader_data * log_rea
 
 struct log_reader_service {
     log_reader_data_t reader;
-    celix_status_t (*getLog)(log_reader_data_t reader, apr_pool_t *memory_pool, LINKED_LIST *list);
+    celix_status_t (*getLog)(log_reader_data_t reader, apr_pool_t *memory_pool, linked_list_t *list);
     celix_status_t (*addLogListener)(log_reader_data_t reader, log_listener_t listener);
     celix_status_t (*removeLogListener)(log_reader_data_t reader, log_listener_t listener);
     celix_status_t (*removeAllLogListener)(log_reader_data_t reader);

Modified: incubator/celix/trunk/log_service/public/include/log_service.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_service/public/include/log_service.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_service/public/include/log_service.h (original)
+++ incubator/celix/trunk/log_service/public/include/log_service.h Wed Dec  5 09:05:46 2012
@@ -47,7 +47,7 @@ typedef enum log_level log_level_t;
 struct log_service {
     log_service_data_t logger;
     celix_status_t (*log)(log_service_data_t logger, log_level_t level, char * message);
-    celix_status_t (*logSr)(log_service_data_t logger, SERVICE_REFERENCE reference, log_level_t level, char * message);
+    celix_status_t (*logSr)(log_service_data_t logger, service_reference_t reference, log_level_t level, char * message);
 };
 
 typedef struct log_service *log_service_t;

Modified: incubator/celix/trunk/log_writer/private/src/log_writer.c
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/log_writer/private/src/log_writer.c?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/log_writer/private/src/log_writer.c (original)
+++ incubator/celix/trunk/log_writer/private/src/log_writer.c Wed Dec  5 09:05:46 2012
@@ -74,7 +74,7 @@ void service_destroy(void * userData) {
 
 celix_status_t logListener_logged(log_listener_t listener, log_entry_t entry) {
 	celix_status_t status = CELIX_SUCCESS;
-    MODULE module = NULL;
+    module_t module = NULL;
     char *sName = NULL;
 
     status = bundle_getCurrentModule(entry->bundle, &module);

Modified: incubator/celix/trunk/remote_services/calc_shell/private/src/add_command.c
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/remote_services/calc_shell/private/src/add_command.c?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/remote_services/calc_shell/private/src/add_command.c (original)
+++ incubator/celix/trunk/remote_services/calc_shell/private/src/add_command.c Wed Dec  5 09:05:46 2012
@@ -59,7 +59,7 @@ void addCommand_destroy(COMMAND command)
 
 void addCommand_execute(COMMAND command, char *line, void (*out)(char *), void (*err)(char *)) {
 	celix_status_t status = CELIX_SUCCESS;
-    SERVICE_REFERENCE exampleService = NULL;
+    service_reference_t exampleService = NULL;
 
     status = bundleContext_getServiceReference(command->bundleContext, (char *) EXAMPLE_SERVICE, &exampleService);
     if (status == CELIX_SUCCESS) {

Modified: incubator/celix/trunk/remote_services/calc_shell/private/src/calc_shell_activator.c
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/remote_services/calc_shell/private/src/calc_shell_activator.c?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/remote_services/calc_shell/private/src/calc_shell_activator.c (original)
+++ incubator/celix/trunk/remote_services/calc_shell/private/src/calc_shell_activator.c Wed Dec  5 09:05:46 2012
@@ -36,13 +36,13 @@
 #include "sqrt_command.h"
 
 struct activator {
-	SERVICE_REGISTRATION addCommand;
+	service_registration_t addCommand;
 	COMMAND addCmd;
 
-	SERVICE_REGISTRATION subCommand;
+	service_registration_t subCommand;
 	COMMAND subCmd;
 
-	SERVICE_REGISTRATION sqrtCommand;
+	service_registration_t sqrtCommand;
 	COMMAND sqrtCmd;
 };
 

Modified: incubator/celix/trunk/remote_services/calc_shell/private/src/sqrt_command.c
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/remote_services/calc_shell/private/src/sqrt_command.c?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/remote_services/calc_shell/private/src/sqrt_command.c (original)
+++ incubator/celix/trunk/remote_services/calc_shell/private/src/sqrt_command.c Wed Dec  5 09:05:46 2012
@@ -59,7 +59,7 @@ void sqrtCommand_destroy(COMMAND command
 
 void sqrtCommand_execute(COMMAND command, char *line, void (*out)(char *), void (*err)(char *)) {
 	celix_status_t status = CELIX_SUCCESS;
-    SERVICE_REFERENCE exampleService = NULL;
+    service_reference_t exampleService = NULL;
     apr_pool_t *memory_pool = NULL;
     apr_pool_t *bundle_memory_pool = NULL;
 

Modified: incubator/celix/trunk/remote_services/calc_shell/private/src/sub_command.c
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/remote_services/calc_shell/private/src/sub_command.c?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/remote_services/calc_shell/private/src/sub_command.c (original)
+++ incubator/celix/trunk/remote_services/calc_shell/private/src/sub_command.c Wed Dec  5 09:05:46 2012
@@ -59,7 +59,7 @@ void subCommand_destroy(COMMAND command)
 
 void subCommand_execute(COMMAND command, char *line, void (*out)(char *), void (*err)(char *)) {
 	celix_status_t status = CELIX_SUCCESS;
-    SERVICE_REFERENCE exampleService = NULL;
+    service_reference_t exampleService = NULL;
     apr_pool_t *memory_pool = NULL;
     apr_pool_t *bundle_memory_pool = NULL;
 

Modified: incubator/celix/trunk/remote_services/discovery/private/include/discovery.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/remote_services/discovery/private/include/discovery.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/remote_services/discovery/private/include/discovery.h (original)
+++ incubator/celix/trunk/remote_services/discovery/private/include/discovery.h Wed Dec  5 09:05:46 2012
@@ -37,12 +37,12 @@ celix_status_t discovery_stop(discovery_
 celix_status_t discovery_endpointAdded(void *handle, endpoint_description_t endpoint, char *machtedFilter);
 celix_status_t discovery_endpointRemoved(void *handle, endpoint_description_t endpoint, char *machtedFilter);
 
-celix_status_t discovery_endpointListenerAdding(void * handle, SERVICE_REFERENCE reference, void **service);
-celix_status_t discovery_endpointListenerAdded(void * handle, SERVICE_REFERENCE reference, void * service);
-celix_status_t discovery_endpointListenerModified(void * handle, SERVICE_REFERENCE reference, void * service);
-celix_status_t discovery_endpointListenerRemoved(void * handle, SERVICE_REFERENCE reference, void * service);
+celix_status_t discovery_endpointListenerAdding(void * handle, service_reference_t reference, void **service);
+celix_status_t discovery_endpointListenerAdded(void * handle, service_reference_t reference, void * service);
+celix_status_t discovery_endpointListenerModified(void * handle, service_reference_t reference, void * service);
+celix_status_t discovery_endpointListenerRemoved(void * handle, service_reference_t reference, void * service);
 
-celix_status_t discovery_updateEndpointListener(discovery_t discovery, SERVICE_REFERENCE reference, endpoint_listener_t service);
+celix_status_t discovery_updateEndpointListener(discovery_t discovery, service_reference_t reference, endpoint_listener_t service);
 
 
 #endif /* DISCOVERY_H_ */
--- incubator/celix/trunk/framework/public/include/version.h (original)
+++ incubator/celix/trunk/framework/public/include/version.h Wed Dec  5 09:05:46 2012
@@ -38,12 +38,12 @@
  */
 
 /**
  * The definition of the VERSION abstract data type.
  */
-typedef struct version * VERSION;
+typedef struct version * version_t;
 
 /**
  * Creates a new VERSION using the supplied arguments.
  *
  * @param pool The pool to create the version on.
  * @param major Major component of the version identifier.
@@ -52,14 +52,14 @@ typedef struct version * VERSION;
  * @param qualifier Qualifier component of the version identifier. If
  *        <code>null</code> is specified, then the qualifier will be set to
  *        the empty string.
  * @param version The created VERSION
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
  * 		- CELIX_ENOMEM If allocating memory for <code>version</code> failed.
  * 		- CELIX_ILLEGAL_ARGUMENT If the numerical components are negative
  * 		  or the qualifier string is invalid.
  */
-celix_status_t version_createVersion(apr_pool_t *pool, int major, int minor, int micro, char * qualifier, VERSION *version);
+celix_status_t version_createVersion(apr_pool_t *pool, int major, int minor, int micro, char * qualifier, version_t *version);
 
 /**
  * Creates a clone of <code>version</code> allocated on <code>pool</code>.
@@ -73,7 +73,7 @@ celix_status_t version_createVersion(apr
  * 		- CELIX_ILLEGAL_ARGUMENT If the numerical components are negative
  * 		  or the qualifier string is invalid.
  */
-celix_status_t version_clone(VERSION version, apr_pool_t *pool, VERSION *clone);
+celix_status_t version_clone(version_t version, apr_pool_t *pool, version_t *clone);
 
 /**
  * Creates a version identifier from the specified string.
@@ -95,27 +95,27 @@ celix_status_t version_clone(VERSION ver
  *
  * @param pool The pool to create the version on.
  * @param versionStr String representation of the version identifier.
  * @param version The created VERSION
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
  * 		- CELIX_ENOMEM If allocating memory for <code>version</code> failed.
  * 		- CELIX_ILLEGAL_ARGUMENT If the numerical components are negative,
  * 		  	the qualifier string is invalid or <code>versionStr</code> is impropertly formatted.
  */
-celix_status_t version_createVersionFromString(apr_pool_t *pool, char * versionStr, VERSION *version);
+celix_status_t version_createVersionFromString(apr_pool_t *pool, char * versionStr, version_t *version);
 
 /**
  * The empty version "0.0.0".
  *
  * @param pool The pool to create the version on.
  * @param version The created VERSION
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
  * 		- CELIX_ENOMEM If allocating memory for <code>version</code> failed.
  * 		- CELIX_ILLEGAL_ARGUMENT If the numerical components are negative,
  * 		  	the qualifier string is invalid or <code>versionStr</code> is impropertly formatted.
  */
-celix_status_t version_createEmptyVersion(apr_pool_t *pool, VERSION *version);
+celix_status_t version_createEmptyVersion(apr_pool_t *pool, version_t *version);
 
 /**
  * Compares this <code>Version</code> object to another object.
@@ -135,14 +135,14 @@ celix_status_t version_createEmptyVersio
  * major, minor and micro components are equal and the qualifier component
  * is equal (using <code>String.compareTo</code>).
  *
  * @param version The <code>VERSION</code> to be compared with <code>compare</code>.
  * @param compare The <code>VERSION</code> to be compared with <code>version</code>.
  * @param result A negative integer, zero, or a positive integer if <code>version</code> is
  *         less than, equal to, or greater than the <code>compare</code>.
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
  */
-celix_status_t version_compareTo(VERSION version, VERSION compare, int *result);
+celix_status_t version_compareTo(version_t version, version_t compare, int *result);
 
 /**
  * Returns the string representation of <code>version</code> identifier.
@@ -153,13 +153,13 @@ celix_status_t version_compareTo(VERSION
  * <code>major.minor.micro.qualifier</code> otherwise.
  *
  * @return The string representation of this version identifier.
  * @param version The <code>VERSION</code> to get the string representation from.
  * @param pool The pool on which the string has to be allocated.
  * @param string Pointer to the string (char *) in which the result will be placed.
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
  */
-celix_status_t version_toString(VERSION version, apr_pool_t *pool, char **string);
+celix_status_t version_toString(version_t version, apr_pool_t *pool, char **string);
 
 /**
  * @}
@@ -38,12 +38,12 @@
 
 /**
- * The definition of the VERSION abstract data type.
+ * The definition of the version_t abstract data type.
  */
@@ -38,12 +38,12 @@
 
 /**
- * Creates a new VERSION using the supplied arguments.
+ * Creates a new version_t using the supplied arguments.
  *
  * @param pool The pool to create the version on.
@@ -52,14 +52,14 @@ typedef struct version * VERSION;
  *        <code>null</code> is specified, then the qualifier will be set to
  *        the empty string.
- * @param version The created VERSION
+ * @param version The created version_t
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
@@ -95,27 +95,27 @@ celix_status_t version_clone(VERSION ver
  * @param pool The pool to create the version on.
  * @param versionStr String representation of the version identifier.
- * @param version The created VERSION
+ * @param version The created version_t
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
@@ -95,27 +95,27 @@ celix_status_t version_clone(VERSION ver
  *
  * @param pool The pool to create the version on.
- * @param version The created VERSION
+ * @param version The created version_t
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
@@ -135,14 +135,14 @@ celix_status_t version_createEmptyVersio
  * is equal (using <code>String.compareTo</code>).
  *
- * @param version The <code>VERSION</code> to be compared with <code>compare</code>.
- * @param compare The <code>VERSION</code> to be compared with <code>version</code>.
+ * @param version The <code>version_t</code> to be compared with <code>compare</code>.
+ * @param compare The <code>version_t</code> to be compared with <code>version</code>.
  * @param result A negative integer, zero, or a positive integer if <code>version</code> is
  *         less than, equal to, or greater than the <code>compare</code>.
@@ -153,13 +153,13 @@ celix_status_t version_compareTo(VERSION
  *
  * @return The string representation of this version identifier.
- * @param version The <code>VERSION</code> to get the string representation from.
+ * @param version The <code>version_t</code> to get the string representation from.
  * @param pool The pool on which the string has to be allocated.
  * @param string Pointer to the string (char *) in which the result will be placed.

Modified: incubator/celix/trunk/framework/public/include/version_range.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/version_range.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================
--- incubator/celix/trunk/framework/public/include/version_range.h (original)
+++ incubator/celix/trunk/framework/public/include/version_range.h Wed Dec  5 09:05:46 2012
@@ -39,12 +39,12 @@
 #include "celix_errno.h"
 
 /**
  * Type definition for the VERSION_RANGE abstract data type.
  */
-typedef struct versionRange * VERSION_RANGE;
+typedef struct versionRange * version_range_t;
 
 /**
- * Creates a new <code>VERSION_RANGE</code>.
+ * Creates a new <code>version_range_t</code>.
  *
  * @param pool The pool in which the version range is created
  * @param low Lower bound version
@@ -56,7 +56,7 @@ typedef struct versionRange * VERSION_RA
  * 		- CELIX_SUCCESS when no errors are encountered.
  * 		- CELIX_ENOMEM If allocating memory for <code>versionRange</code> failed.
  */
-celix_status_t versionRange_createVersionRange(apr_pool_t *pool, VERSION low, bool isLowInclusive, VERSION high, bool isHighInclusive, VERSION_RANGE *versionRange);
+celix_status_t versionRange_createVersionRange(apr_pool_t *pool, version_t low, bool isLowInclusive, version_t high, bool isHighInclusive, version_range_t *versionRange);
 
 /**
  * Creates an infinite version range using ::version_createEmptyVersion for the low version,
@@ -68,7 +68,7 @@ celix_status_t versionRange_createVersio
  * 		- CELIX_SUCCESS when no errors are encountered.
  * 		- CELIX_ENOMEM If allocating memory for <code>range</code> failed.
  */
-celix_status_t versionRange_createInfiniteVersionRange(apr_pool_t *pool, VERSION_RANGE *range);
+celix_status_t versionRange_createInfiniteVersionRange(apr_pool_t *pool, version_range_t *range);
 
 /**
  * Determine if the specified version is part of the version range or not.
@@ -79,7 +79,7 @@ celix_status_t versionRange_createInfini
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
  */
-celix_status_t versionRange_isInRange(VERSION_RANGE versionRange, VERSION version, bool *inRange);
+celix_status_t versionRange_isInRange(version_range_t versionRange, version_t version, bool *inRange);
 
 /**
  * Parses a version range from the specified string.
@@ -97,14 +97,14 @@ celix_status_t versionRange_isInRange(VE
  *
  * @param pool The pool in which the range is created.
  * @param rangeStr String representation of the version range.
  * @param range The created VERSION_RANGE.
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.
  * 		- CELIX_ENOMEM If allocating memory for <code>versionRange</code> failed.
  * 		- CELIX_ILLEGAL_ARGUMENT If the numerical components are negative,
  * 		  	the qualifier string is invalid or <code>versionStr</code> is impropertly formatted.
  */
-celix_status_t versionRange_parse(apr_pool_t *pool, char * rangeStr, VERSION_RANGE *range);
+celix_status_t versionRange_parse(apr_pool_t *pool, char * rangeStr, version_range_t *range);
 
 /**
  * @}
@@ -39,12 +39,12 @@
 
 /**
- * Type definition for the VERSION_RANGE abstract data type.
+ * Type definition for the version_range_t abstract data type.
  */
@@ -97,14 +97,14 @@ celix_status_t versionRange_isInRange(VE
  * @param pool The pool in which the range is created.
  * @param rangeStr String representation of the version range.
- * @param range The created VERSION_RANGE.
+ * @param range The created version_range_t.
  * @return Status code indication failure or success:
  * 		- CELIX_SUCCESS when no errors are encountered.

Modified: incubator/celix/trunk/framework/public/include/wire.h
URL: http://svn.apache.org/viewvc/incubator/celix/trunk/framework/public/include/wire.h?rev=1417320&r1=1417319&r2=1417320&view=diff
==============================================================================